@@ -97,17 +97,23 @@ def predict(
         arr[sx:ex, sy:ey, idx] = pred_reshaped
         weights[sx:ex, sy:ey, idx] = pred_weights_reshaped
 
-    weights = weights[:, :, :, 0]
-    arr = arr[:, :, :, 0]
+        import pdb; pdb.set_trace()
 
     weights_sum = np.sum(weights, axis=2)
     weights_norm = (weights[:, :, :, 0] / weights_sum)[:, :, :, np.newaxis]
 
+    # What is going on with dimensions here?
+    import pdb; pdb.set_trace()
+
+    weights = weights[:, :, :, 0]
+    arr = arr[:, :, :, 0]
+
     merged = None
     if merge_method == "mean":
         merged = np.average(arr, axis=2, weights=weights_norm)
 
     elif merge_method == "max":
+        import pdb; pdb.set_trace()
         mask = np.argmax(weights, axis=-1)[:, :, np.newaxis] == np.tile(
             np.arange(0, weights.shape[2]), weights.shape[0] * weights.shape[1]
         ).reshape(weights.shape[0], weights.shape[1], weights.shape[2])
